RFR: ZGC: Turn off VerifyDuringStartup

Stefan Karlsson stefan.karlsson at oracle.com
Tue May 29 13:06:17 UTC 2018


Hi all,

ZGC doesn't allow verification outside of the mark end pause. The 
following patch forcefully turns VerifyDuringStartup off, just like we 
do with VerifyBeforeExit.

diff --git a/src/hotspot/share/gc/z/zArguments.cpp 
b/src/hotspot/share/gc/z/zArguments.cpp
--- a/src/hotspot/share/gc/z/zArguments.cpp
+++ b/src/hotspot/share/gc/z/zArguments.cpp
@@ -87,7 +87,8 @@
    FLAG_SET_DEFAULT(ClassUnloading, false);
    FLAG_SET_DEFAULT(ClassUnloadingWithConcurrentMark, false);

-  // Verification before exit not (yet) supported
+  // Verification before startup and after exit not (yet) supported
+  FLAG_SET_DEFAULT(VerifyDuringStartup, false);
    FLAG_SET_DEFAULT(VerifyBeforeExit, false);

    // JVMCI not (yet) supported


Thanks,
StefanK


More information about the zgc-dev mailing list